@@ -18,6 +18,15 @@ from mcp_proxy_adapter.core.errors import (
     InternalError,
 )
 
+# CLI module
+# Delayed import of CLI to avoid side effects during server startup
+# CLI can be accessed via entrypoint `mcp-proxy-adapter` or `python -m mcp_proxy_adapter`
+try:
+    from mcp_proxy_adapter.cli import main as cli_main
+except Exception:
+    # Avoid import errors impacting library/server usage
+    cli_main = None
+
 # Экспортируем основные классы и функции для удобного использования
 __all__ = [
     "__version__",
@@ -34,4 +43,5 @@ __all__ = [
     "NotFoundError",
     "TimeoutError",
     "InternalError",
+    "cli_main",
 ]
