@@ -20,6 +20,8 @@ from .app_factory_validators import (
 )
 from .app_factory_certificates import validate_certificates
 from .app_factory_routes import setup_routes
+from mcp_proxy_adapter.commands.builtin_commands import register_builtin_commands
+from mcp_proxy_adapter.commands.help_command import set_app_metadata
 
 
 class AppFactory:
@@ -69,6 +71,15 @@ class AppFactory:
         )
         self.logger.info("🔍 AppFactory: FastAPI app created")
 
+        # Register built-in commands automatically
+        # Pass current_config to enable automatic queue commands registration
+        register_builtin_commands(config_data=current_config)
+        self.logger.info("✅ Built-in commands registered")
+
+        # Store app metadata for help command
+        set_app_metadata(title, description, version)
+        self.logger.info(f"✅ App metadata stored: {title} v{version}")
+
         setup_routes(app)
         app.openapi = lambda: custom_openapi_with_fallback(app)
         return app
