@@ -94,39 +94,13 @@ class LifespanManager:
                         import traceback
                         logger.info(f"🔍 SimpleConfigModel check traceback: {traceback.format_exc()}")
                     
-                    # Also check old formats and new registration section
+                    # Check registration section
                     if not registration_enabled:
-                        proxy_client_config = current_config.get("proxy_client") or {}
-                        proxy_registration_config = current_config.get("proxy_registration") or {}
                         registration_config = current_config.get("registration") or {}
-                        
-                        logger.info(f"🔍 Checking config sections:")
-                        logger.info(f"🔍   proxy_client_config: {proxy_client_config}")
-                        logger.info(f"🔍   proxy_registration_config: {proxy_registration_config}")
-                        logger.info(f"🔍   registration_config: {registration_config}")
-                        logger.info(f"🔍   registration_config type: {type(registration_config)}")
-                        
-                        # Check new format (registration section)
                         if registration_config:
-                            logger.info(f"🔍 registration_config is not empty, checking values...")
                             reg_enabled = registration_config.get("enabled", False)
                             reg_auto_startup = registration_config.get("auto_on_startup", True)
-                            logger.info(f"🔍   reg_enabled: {reg_enabled} (type: {type(reg_enabled)})")
-                            logger.info(f"🔍   reg_auto_startup: {reg_auto_startup} (type: {type(reg_auto_startup)})")
                             registration_enabled = reg_enabled and reg_auto_startup
-                            logger.info(f"🔍 Registration enabled check (registration section): {registration_enabled} (enabled={reg_enabled}, auto_on_startup={reg_auto_startup})")
-                        else:
-                            logger.info(f"🔍 registration_config is empty or None")
-                        
-                        # Check old formats if still not enabled
-                        if not registration_enabled:
-                            logger.info(f"🔍 Checking old formats...")
-                            proxy_client_enabled = proxy_client_config.get("enabled", False)
-                            proxy_registration_enabled = proxy_registration_config.get("enabled", False)
-                            logger.info(f"🔍   proxy_client.enabled: {proxy_client_enabled}")
-                            logger.info(f"🔍   proxy_registration.enabled: {proxy_registration_enabled}")
-                            registration_enabled = proxy_client_enabled or proxy_registration_enabled
-                            logger.info(f"🔍 Registration enabled check (old formats): {registration_enabled}")
                     
                     logger.info(f"🔍 FINAL registration_enabled: {registration_enabled}")
                     if registration_enabled:
@@ -165,6 +139,7 @@ class LifespanManager:
                                     "max_concurrent_jobs": cfg.model.queue_manager.max_concurrent_jobs,
                                     "max_queue_size": cfg.model.queue_manager.max_queue_size,
                                     "per_job_type_limits": cfg.model.queue_manager.per_job_type_limits,
+                                    "completed_job_retention_seconds": cfg.model.queue_manager.completed_job_retention_seconds,
                                 }
                         except Exception as e:
                             logger.debug(f"Could not read queue config from global config: {e}")
@@ -182,6 +157,7 @@ class LifespanManager:
                             in_memory=queue_config.get("in_memory", True),
                             max_queue_size=queue_config.get("max_queue_size"),
                             per_job_type_limits=queue_config.get("per_job_type_limits"),
+                            completed_job_retention_seconds=queue_config.get("completed_job_retention_seconds", 21600),
                         )
                         logger.info("✅ Queue manager initialized")
                     else:
