@@ -17,6 +17,7 @@ class ProxyCredentials:
 
     cert: Optional[Tuple[str, str]]
     verify: Union[bool, str]
+    check_hostname: bool = True  # DNS/hostname verification flag
 
 
 @dataclass
@@ -29,8 +30,6 @@ class RegistrationContext:
     register_endpoint: str
     capabilities: List[str]
     metadata: Dict[str, Any]
-    use_proxy_client: bool
-    proxy_client_config: Dict[str, Any]
     proxy_registration_config: Dict[str, Any]
     credentials: ProxyCredentials
 
