@@ -3,8 +3,7 @@
 Author: Vasiliy Zdanovskiy
 email: vasilyvz@gmail.com
 
-This module is kept for backward compatibility.
-New code should import from mcp_proxy_adapter.api.core.registration instead.
+Re-exports from mcp_proxy_adapter.api.core.registration.
 """
 
 from __future__ import annotations
