@@ -50,8 +50,6 @@ class RegistrationManager:
         self.capabilities: List[str] = []
         self.metadata: Dict[str, Any] = {}
         self.config: Optional[Dict[str, Any]] = None
-        self._use_proxy_client = False
-        self._proxy_client_config: Dict[str, Any] = {}
         self._proxy_registration_config: Dict[str, Any] = {}
         self._registration_credentials: Optional[ProxyCredentials] = None
         self._runtime_credentials: Optional[ProxyCredentials] = None
@@ -67,8 +65,6 @@ class RegistrationManager:
             "capabilities": self.capabilities,
             "metadata": self.metadata,
             "config": self.config,
-            "_use_proxy_client": self._use_proxy_client,
-            "_proxy_client_config": self._proxy_client_config,
             "_proxy_registration_config": self._proxy_registration_config,
             "_registration_credentials": self._registration_credentials,
             "_runtime_credentials": self._runtime_credentials,
@@ -83,8 +79,6 @@ class RegistrationManager:
         self.capabilities = state.get("capabilities", [])
         self.metadata = state.get("metadata", {})
         self.config = state.get("config")
-        self._use_proxy_client = state.get("_use_proxy_client", False)
-        self._proxy_client_config = state.get("_proxy_client_config", {})
         self._proxy_registration_config = state.get("_proxy_registration_config", {})
         self._registration_credentials = state.get("_registration_credentials")
         self._runtime_credentials = state.get("_runtime_credentials")
@@ -114,8 +108,8 @@ class RegistrationManager:
         """
         Register this server with the proxy using JsonRpcClient.
 
-        Supports both ``proxy_client`` (SimpleConfig format) and ``proxy_registration`` (legacy format).
-        Registration is controlled by ``registration.auto_on_startup`` rather than ``proxy_client.enabled``.
+        Uses only the new ``registration`` format from SimpleConfig.
+        Registration is controlled by ``registration.auto_on_startup``.
         """
         context = prepare_registration_context(config, self.logger)
         if context is None:
@@ -133,15 +127,12 @@ class RegistrationManager:
         proxy_host = parsed.hostname or "localhost"
         proxy_port = parsed.port or (443 if parsed.scheme == "https" else 80)
 
-        # Get protocol from context
-        if self._use_proxy_client:
-            proxy_protocol = self._proxy_client_config.get("protocol", "http")
-        else:
-            proxy_protocol = parsed.scheme or "http"
-            cert_config = self._proxy_registration_config.get("certificate", {})
-            ssl_config = self._proxy_registration_config.get("ssl", {})
-            if cert_config.get("cert_file") and ssl_config.get("ca_cert"):
-                proxy_protocol = "mtls"
+        # Get protocol from URL scheme
+        proxy_protocol = parsed.scheme or "http"
+        # Check if mTLS (https with certificates)
+        ssl_config = self._proxy_registration_config.get("ssl", {})
+        if isinstance(ssl_config, dict) and ssl_config.get("cert") and ssl_config.get("ca"):
+            proxy_protocol = "mtls"
 
         # Extract client certificate paths from credentials
         client_cert = None
@@ -172,6 +163,7 @@ class RegistrationManager:
             cert=client_cert,
             key=client_key,
             ca=client_ca,
+            check_hostname=context.credentials.check_hostname,
         )
 
         async def _register() -> Dict[str, Any]:
@@ -287,108 +279,24 @@ class RegistrationManager:
             self._apply_context(context, config)
 
         if context is None:
-            registration_disabled = True
-            try:
-                from mcp_proxy_adapter.config import get_config
+            self.logger.debug("Registration is disabled, heartbeat task will not start")
+            return
 
-                cfg = get_config()
-                if hasattr(cfg, "model") and hasattr(cfg.model, "registration"):
-                    registration_disabled = not cfg.model.registration.enabled
-            except Exception:
-                pass
+        self.logger.info("✅ Registration context available")
+        self.logger.info(
+            f"✅ Context applied: server_name={self.server_name}, proxy_url={self.proxy_url}"
+        )
 
-            proxy_client_config = dict(config.get("proxy_client") or {})
-            proxy_registration_config = dict(config.get("proxy_registration") or {})
-            registration_config = dict(config.get("registration") or {})
-
-            if registration_config and not proxy_registration_config:
-                proxy_registration_config = registration_config
-
-            if (
-                registration_disabled
-                and not proxy_client_config.get("enabled", False)
-                and not proxy_registration_config.get("enabled", False)
-                and not registration_config.get("enabled", False)
-            ):
-                self.logger.debug(
-                    "Registration is disabled, heartbeat task will not start"
-                )
-                return
-
-            self.logger.info(
-                "⚠️  Registration context is None, creating minimal context for heartbeat"
+        if not self._can_start_tasks():
+            self.logger.warning(
+                "⚠️  Cannot start tasks (missing proxy_url, server_name, or server_url)"
             )
-
-            use_proxy_client = bool(proxy_client_config.get("enabled", False))
-            self._use_proxy_client = use_proxy_client
-            self._proxy_client_config = proxy_client_config
-            self._proxy_registration_config = proxy_registration_config
-
-            server_config = dict(config.get("server") or {})
-            host = server_config.get("host", "127.0.0.1")
-            port = server_config.get("port", 8000)
-            protocol = server_config.get("protocol", "http")
-            advertised_host = server_config.get("advertised_host") or host
-            scheme = "https" if protocol in ("https", "mtls") else "http"
-            self.server_url = f"{scheme}://{advertised_host}:{port}"
-
-            if use_proxy_client:
-                self.server_name = (
-                    proxy_client_config.get("server_id")
-                    or proxy_client_config.get("server_name")
-                    or f"mcp-adapter-{host}-{port}"
-                )
-                pc_protocol = proxy_client_config.get("protocol", "http")
-                pc_scheme = "https" if pc_protocol in ("https", "mtls") else "http"
-                pc_host = proxy_client_config.get("host", "localhost")
-                pc_port = proxy_client_config.get("port", 3005)
-                self.proxy_url = f"{pc_scheme}://{pc_host}:{pc_port}"
-                self.capabilities = proxy_client_config.get(
-                    "capabilities", ["jsonrpc", "health"]
-                )
-            else:
-                self.server_name = (
-                    proxy_registration_config.get("server_id")
-                    or proxy_registration_config.get("server_name")
-                    or f"mcp-adapter-{host}-{port}"
-                )
-                proxy_url_candidate = (
-                    proxy_registration_config.get("proxy_url")
-                    or proxy_registration_config.get("server_url")
-                )
-                if proxy_url_candidate:
-                    parsed = urlparse(str(proxy_url_candidate))
-                    proxy_scheme = parsed.scheme or "http"
-                    proxy_host = parsed.hostname or "localhost"
-                    proxy_port = parsed.port or 3005
-                    self.proxy_url = f"{proxy_scheme}://{proxy_host}:{proxy_port}"
-                else:
-                    self.proxy_url = "http://localhost:3005"
-                self.capabilities = proxy_registration_config.get(
-                    "capabilities", ["jsonrpc", "health"]
-                )
-
-            self.metadata = {}
-        else:
-            self.logger.info("✅ Registration context available")
-            self.logger.info(
-                f"✅ Context applied: server_name={self.server_name}, proxy_url={self.proxy_url}"
-            )
-
-            if not self._can_start_tasks():
-                self.logger.warning(
-                    "⚠️  Cannot start tasks (missing proxy_url, server_name, or server_url)"
-                )
-                return
+            return
 
         credentials = self._registration_credentials or resolve_runtime_credentials(
-            self._use_proxy_client,
-            self._proxy_client_config,
             self._proxy_registration_config,
         )
         settings = resolve_heartbeat_settings(
-            self._use_proxy_client,
-            self._proxy_client_config,
             self._proxy_registration_config,
             self.proxy_url or "http://localhost:3005",
         )
@@ -434,13 +342,10 @@ class RegistrationManager:
             return
 
         credentials = self._runtime_credentials or resolve_runtime_credentials(
-            self._use_proxy_client,
-            self._proxy_client_config,
             self._proxy_registration_config,
         )
         endpoint = resolve_unregister_endpoint(
-            self._use_proxy_client,
-            self._proxy_client_config,
+            self._proxy_registration_config,
         )
 
         assert self.proxy_url is not None
@@ -465,13 +370,10 @@ class RegistrationManager:
             return
 
         credentials = self._runtime_credentials or resolve_runtime_credentials(
-            self._use_proxy_client,
-            self._proxy_client_config,
             self._proxy_registration_config,
         )
         endpoint = resolve_unregister_endpoint(
-            self._use_proxy_client,
-            self._proxy_client_config,
+            self._proxy_registration_config,
         )
 
         assert self.proxy_url is not None
