@@ -35,7 +35,6 @@ def create_heartbeat_task(
 
     # Import here to avoid circular import
     from mcp_proxy_adapter.api.core.registration_manager import (
-        get_registration_status,
         set_registration_status,
         get_stop_flag,
     )
@@ -43,11 +42,12 @@ def create_heartbeat_task(
     async def heartbeat_loop() -> None:
         # Extract protocol, host, port from proxy_url for JsonRpcClient
         from urllib.parse import urlparse
+
         parsed = urlparse(proxy_url)
         client_protocol = parsed.scheme or "http"
         client_host = parsed.hostname or "localhost"
         client_port = parsed.port or (443 if client_protocol == "https" else 80)
-        
+
         # Extract cert and key from credentials if available
         client_cert = None
         client_key = None
@@ -56,10 +56,10 @@ def create_heartbeat_task(
             client_cert, client_key = credentials.cert
         if isinstance(credentials.verify, str):
             client_ca = credentials.verify
-        
+
         # Lazy import to avoid circular dependency
         from mcp_proxy_adapter.client.jsonrpc_client import JsonRpcClient
-        
+
         client = JsonRpcClient(
             protocol=client_protocol,
             host=client_host,
@@ -67,6 +67,7 @@ def create_heartbeat_task(
             cert=client_cert,
             key=client_key,
             ca=client_ca,
+            check_hostname=credentials.check_hostname,
         )
         try:
             while True:
@@ -76,70 +77,50 @@ def create_heartbeat_task(
                     if should_stop:
                         logger.info("🛑 Stop flag set, stopping heartbeat loop")
                         break
-                    
-                    # Check registration status (thread-safe with mutex)
-                    is_registered = await get_registration_status()
 
-                    if not is_registered:
-                        # Attempt registration
-                        if registration_manager._registration_config:
+                    if not getattr(registration_manager, "registered", False):
+                        config_for_registration = getattr(
+                            registration_manager, "_registration_config", None
+                        )
+                        if config_for_registration:
                             logger.info(
-                                "📡 Attempting registration via heartbeat loop..."
+                                "📡 Attempting proxy registration before heartbeat"
                             )
                             try:
-                                success = await registration_manager.register_with_proxy(
-                                    registration_manager._registration_config
+                                await registration_manager.register_with_proxy(
+                                    config_for_registration
                                 )
-                                if success:
-                                    await set_registration_status(True)
-                                    logger.info(
-                                        "✅ Registration successful via heartbeat loop"
-                                    )
-                                else:
-                                    # Registration failed - status already reset if "already registered"
-                                    logger.warning(
-                                        "⚠️  Registration failed, will retry on next heartbeat"
-                                    )
-                            except Exception as exc:
-                                # Check if error is "already registered"
-                                error_msg = str(exc).lower()
-                                if "already registered" in error_msg:
-                                    logger.warning(
-                                        "⚠️  Server already registered, resetting status"
-                                    )
-                                    await set_registration_status(False)
-                                else:
-                                    logger.warning(
-                                        f"⚠️  Registration error: {exc}, will retry on next heartbeat"
-                                    )
-                        # Wait shorter interval before retry
-                        await asyncio.sleep(min(5, interval))
-                    else:
-                        # Send heartbeat using full URL from settings
-                        heartbeat_url = settings.url
-                        logger.info(f"💓 Sending heartbeat to {heartbeat_url}")
-                        try:
-                            await client.heartbeat_to_proxy(
-                                proxy_url=heartbeat_url,
-                                server_name=server_name,
-                                server_url=server_url,
-                                capabilities=list(capabilities),
-                                metadata=metadata,
-                                cert=credentials.cert,
-                                verify=credentials.verify,
-                            )
-                            logger.info("💓 Heartbeat sent successfully")
-                        except Exception as exc:
-                            # Check if error is "already registered" or "not found"
-                            error_msg = str(exc).lower()
-                            if "already registered" in error_msg or "not found" in error_msg:
+                            except Exception as exc:  # noqa: BLE001
                                 logger.warning(
-                                    "⚠️  Server not found or already registered, resetting status"
+                                    "⚠️  Initial registration attempt failed: %s", exc
                                 )
-                                await set_registration_status(False)
-                            else:
-                                logger.error(f"💓 Heartbeat error: {exc}")
+                                await asyncio.sleep(min(5, interval))
+                                continue
+
+                    heartbeat_url = settings.url
+                    logger.info(
+                        "💓 Sending heartbeat with registration payload to %s",
+                        heartbeat_url,
+                    )
+                    try:
+                        await client.heartbeat_to_proxy(
+                            proxy_url=heartbeat_url,
+                            server_name=server_name,
+                            server_url=server_url,
+                            capabilities=list(capabilities),
+                            metadata=metadata,
+                            cert=credentials.cert,
+                            verify=credentials.verify,
+                        )
+                        registration_manager.registered = True
+                        await set_registration_status(True)
+                        logger.info("💓 Heartbeat/registration acknowledged by proxy")
                         await asyncio.sleep(interval)
+                    except Exception as exc:
+                        registration_manager.registered = False
+                        await set_registration_status(False)
+                        logger.warning("⚠️  Heartbeat/registration failed: %s", exc)
+                        await asyncio.sleep(min(5, interval))
                 except asyncio.CancelledError:
                     raise
                 except Exception as exc:  # noqa: BLE001
@@ -165,11 +146,12 @@ async def unregister_from_proxy(
 
     # Extract protocol, host, port from proxy_url for JsonRpcClient
     from urllib.parse import urlparse
+
     parsed = urlparse(proxy_url)
     client_protocol = parsed.scheme or "http"
     client_host = parsed.hostname or "localhost"
     client_port = parsed.port or (443 if client_protocol == "https" else 80)
-    
+
     # Extract cert and key from credentials if available
     client_cert = None
     client_key = None
@@ -178,10 +160,10 @@ async def unregister_from_proxy(
         client_cert, client_key = credentials.cert
     if isinstance(credentials.verify, str):
         client_ca = credentials.verify
-    
+
     # Lazy import to avoid circular dependency
     from mcp_proxy_adapter.client.jsonrpc_client import JsonRpcClient
-    
+
     client = JsonRpcClient(
         protocol=client_protocol,
         host=client_host,
@@ -189,6 +171,7 @@ async def unregister_from_proxy(
         cert=client_cert,
         key=client_key,
         ca=client_ca,
+        check_hostname=credentials.check_hostname,
     )
     try:
         full_url = f"{proxy_url}{endpoint}"
