@@ -34,6 +34,9 @@ async def execute_command(
 ) -> Dict[str, Any]:
     """Execute a registered command by name with parameters.
 
+    If command has use_queue=True, command will be executed via queue and job_id will be returned.
+    Otherwise, command will be executed synchronously and result will be returned.
+
     Raises MethodNotFoundError if command is not found.
     Wraps unexpected exceptions into InternalError.
     """
@@ -61,7 +64,53 @@ async def execute_command(
                     "roles": user_roles or [],
                 }
 
-        # Execute with timeout
+        # Check if command should be executed via queue
+        use_queue = getattr(command_class, "use_queue", False)
+        
+        if use_queue:
+            # Execute via queue - return job_id
+            try:
+                from mcp_proxy_adapter.integrations.queuemgr_integration import (
+                    get_global_queue_manager,
+                )
+                from mcp_proxy_adapter.commands.queue.jobs import CommandExecutionJob
+                import uuid
+                
+                queue_manager = await get_global_queue_manager()
+                job_id = str(uuid.uuid4())
+                
+                # Prepare job parameters
+                job_params = {
+                    "command": command_name,
+                    "params": params or {},
+                    "context": context,
+                }
+                
+                # Add job to queue
+                await queue_manager.add_job(CommandExecutionJob, job_id, job_params)
+                
+                # Start job automatically
+                try:
+                    await queue_manager.start_job(job_id)
+                    logger.info(f"Command '{command_name}' queued and started as job {job_id}")
+                    status = "running"
+                except Exception as start_exc:
+                    logger.warning(f"Failed to auto-start job {job_id}: {start_exc}")
+                    status = "queued"
+                
+                # Return job_id instead of result
+                return {
+                    "success": True,
+                    "job_id": job_id,
+                    "status": status,
+                    "message": f"Command '{command_name}' has been queued for execution",
+                }
+                
+            except Exception as exc:
+                logger.exception(f"Failed to queue command '{command_name}': {exc}")
+                raise InternalError(f"Failed to queue command: {str(exc)}")
+
+        # Execute synchronously (default behavior)
         # Ensure params is a dict, not None
         if params is None:
             params = {}
@@ -192,3 +241,39 @@ async def get_commands_list() -> Dict[str, Dict[str, Any]]:
         schema = cls.get_schema()
         result[name] = {"name": name, "schema": schema, "description": schema.get("description", "")}
     return result
+
+
+async def handle_heartbeat() -> Dict[str, Any]:
+    """Handle heartbeat request from proxy.
+    
+    This endpoint is used by the proxy to check if the server is alive.
+    Returns server status and metadata.
+    """
+    logger = get_global_logger()
+    logger.debug("💓 Heartbeat request received")
+    
+    # Get server info from config if available
+    server_name = "mcp-proxy-adapter"
+    server_url = "http://localhost:8080"
+    
+    try:
+        from mcp_proxy_adapter.config import get_config
+        cfg = get_config()
+        if hasattr(cfg, "model") and hasattr(cfg.model, "server"):
+            server_config = cfg.model.server
+            if hasattr(server_config, "name"):
+                server_name = server_config.name or server_name
+            if hasattr(server_config, "host") and hasattr(server_config, "port"):
+                protocol = "https" if (hasattr(server_config, "ssl") and server_config.ssl and server_config.ssl.enabled) else "http"
+                host = server_config.host or "localhost"
+                port = server_config.port or 8080
+                server_url = f"{protocol}://{host}:{port}"
+    except Exception:
+        pass  # Use defaults if config is not available
+    
+    return {
+        "status": "ok",
+        "server_name": server_name,
+        "server_url": server_url,
+        "timestamp": time.time(),
+    }
