@@ -26,7 +26,22 @@ class JsonRpcClient(ProxyApiMixin, QueueApiMixin, CommandApiMixin):
         cert: Optional[str] = None,
         key: Optional[str] = None,
         ca: Optional[str] = None,
+        check_hostname: bool = False,
     ) -> None:
+        """
+        Initialize JSON-RPC client.
+        
+        Args:
+            protocol: Transport protocol (http, https, mtls)
+            host: Server hostname
+            port: Server port
+            token_header: Header name for authentication token
+            token: Authentication token value
+            cert: Path to client certificate file
+            key: Path to client private key file
+            ca: Path to CA certificate file
+            check_hostname: Whether to verify hostname in SSL connections
+        """
         super().__init__(
             protocol=protocol,
             host=host,
@@ -36,6 +51,7 @@ class JsonRpcClient(ProxyApiMixin, QueueApiMixin, CommandApiMixin):
             cert=cert,
             key=key,
             ca=ca,
+            check_hostname=check_hostname,
         )
 
 
