@@ -11,6 +11,7 @@ from typing import Any, Dict, Optional, Tuple, Union, cast
 
 import httpx
 
+from mcp_proxy_adapter.core.ssl_utils import SSLUtils
 
 class JsonRpcTransport:
     """Base transport class providing HTTP primitives."""
@@ -72,10 +73,23 @@ class JsonRpcTransport:
             if isinstance(verify, str):
                 verify_path = Path(verify)
                 if verify_path.exists():
-                    import ssl
-
-                    ssl_context = ssl.create_default_context(cafile=str(verify_path))
-                    ssl_context.check_hostname = self._check_hostname
+                    # Extract client cert and key from self.cert tuple if available
+                    client_cert = None
+                    client_key = None
+                    if self.cert and isinstance(self.cert, tuple) and len(self.cert) == 2:
+                        client_cert = self.cert[0]
+                        client_key = self.cert[1]
+                    
+                    ssl_context = SSLUtils.create_client_ssl_context(
+                        ca_cert=str(verify_path),
+                        client_cert=client_cert,
+                        client_key=client_key,
+                        verify=True,
+                        check_hostname=self._check_hostname,
+                    )
+                    # Ensure check_hostname is set correctly (SSLManager may not apply it)
+                    if hasattr(ssl_context, 'check_hostname'):
+                        ssl_context.check_hostname = self._check_hostname
                     verify = ssl_context
                 else:
                     # Path doesn't exist, but it's a string - treat as False to avoid errors
@@ -110,6 +124,38 @@ class JsonRpcTransport:
         response = await client.get(f"{self.base_url}/openapi.json", headers=self.headers)
         response.raise_for_status()
         return cast(Dict[str, Any], response.json())
+    
+    async def jsonrpc_batch_call(
+        self,
+        requests: List[Dict[str, Any]],
+    ) -> List[Dict[str, Any]]:
+        """
+        Execute batch JSON-RPC requests.
+        
+        Args:
+            requests: List of JSON-RPC request dictionaries, each containing:
+                - method: Method name
+                - params: Method parameters (optional)
+                - id: Request ID (optional)
+        
+        Returns:
+            List of JSON-RPC responses in the same order as requests
+            
+        Example:
+            requests = [
+                {"jsonrpc": "2.0", "method": "echo", "params": {"message": "Hello"}, "id": 1},
+                {"jsonrpc": "2.0", "method": "help", "params": {}, "id": 2},
+            ]
+            responses = await client.jsonrpc_batch_call(requests)
+        """
+        client = await self._get_client()
+        response = await client.post(
+            f"{self.base_url}/api/jsonrpc/batch",
+            json=requests,
+            headers=self.headers,
+        )
+        response.raise_for_status()
+        return cast(List[Dict[str, Any]], response.json())
 
     async def cmd_call(
         self,
