@@ -71,6 +71,8 @@ class Command(ABC):
     source_url: ClassVar[str] = ""
     # Result class
     result_class: ClassVar[Type[CommandResult]]
+    # Use queue for execution (if True, command will be executed via queue and return job_id)
+    use_queue: ClassVar[bool] = False
 
     @abstractmethod
     async def execute(self, **kwargs) -> CommandResult:
@@ -91,9 +93,13 @@ class Command(ABC):
         Get JSON schema for command parameters.
 
         Returns:
-            JSON schema.
+            JSON schema with metadata including use_queue flag.
         """
-        return {"type": "object", "properties": {}, "additionalProperties": False}
+        schema = {"type": "object", "properties": {}, "additionalProperties": False}
+        # Add metadata about queue usage
+        if hasattr(cls, "use_queue") and cls.use_queue:
+            schema["x-use-queue"] = True
+        return schema
 
     @classmethod
     def get_result_schema(cls) -> Dict[str, Any]:
