@@ -333,6 +333,65 @@ class CommandRegistry:
         self._manager.clear(self._commands, self._instances, self._command_types)
         self.logger.info("Cleared all commands")
 
+    async def reload_system(self, config_path: Optional[str] = None) -> Dict[str, Any]:
+        """
+        Reload system configuration and commands.
+
+        Args:
+            config_path: Optional path to configuration file to reload
+
+        Returns:
+            Dictionary with reload information
+        """
+        result: Dict[str, Any] = {
+            "config_reloaded": False,
+            "builtin_commands": 0,
+            "custom_commands": 0,
+            "loaded_commands": 0,
+            "remote_commands": 0,
+            "total_commands": 0,
+        }
+
+        try:
+            # Reload config if path provided
+            if config_path:
+                from mcp_proxy_adapter.config import get_config
+                try:
+                    config = get_config()
+                    config.config_path = config_path
+                    config.load_config()
+                    result["config_reloaded"] = True
+                    self.logger.info(f"✅ Configuration reloaded from: {config_path}")
+                except Exception as e:
+                    self.logger.error(f"❌ Failed to reload config: {e}")
+                    result["config_error"] = str(e)
+
+            # Count current commands by type
+            for cmd_name, cmd_type in self._command_types.items():
+                if cmd_type == "builtin":
+                    result["builtin_commands"] += 1
+                elif cmd_type == "custom":
+                    result["custom_commands"] += 1
+                elif cmd_type == "loaded":
+                    result["loaded_commands"] += 1
+                else:
+                    result["remote_commands"] += 1
+
+            result["total_commands"] = len(self._commands)
+
+            self.logger.info(
+                f"✅ System reload completed: {result['total_commands']} commands "
+                f"(builtin: {result['builtin_commands']}, "
+                f"custom: {result['custom_commands']}, "
+                f"loaded: {result['loaded_commands']})"
+            )
+
+        except Exception as e:
+            self.logger.error(f"❌ System reload failed: {e}")
+            result["error"] = str(e)
+
+        return result
+
     def get_all_commands_info(self) -> Dict[str, Any]:
         """
         Get comprehensive information about all commands.
