@@ -16,13 +16,18 @@ class EchoCommandResult(SuccessResult):
     """Result for echo command."""
 
     def __init__(self, message: str, timestamp: Optional[str] = None):
+        """
+        Initialize echo command result.
+
+        Args:
+            message: Echo message
+            timestamp: Optional timestamp
+        """
         data = {"message": message}
         if timestamp:
             data["timestamp"] = timestamp
         super().__init__(data=data, message=message)
 
-    @classmethod
-
 
 class EchoCommand(Command):
     """Echo command for testing purposes."""
@@ -44,5 +49,3 @@ class EchoCommand(Command):
         await asyncio.sleep(0.001)
 
         return EchoCommandResult(message=message, timestamp=timestamp)
-
-    @classmethod
