@@ -15,6 +15,43 @@ from mcp_proxy_adapter.core.logging import get_global_logger
 # Добавляем логирование
 logger = logging.getLogger("mcp_proxy_adapter.commands.help_command")
 
+# Global storage for app metadata
+_app_metadata: Dict[str, str] = {
+    "name": "MCP-Proxy API Service",
+    "description": "JSON-RPC API for microservice command execution",
+    "version": "1.0.0",
+}
+
+
+def set_app_metadata(name: str, description: str, version: str) -> None:
+    """
+    Set application metadata for help command.
+
+    Args:
+        name: Application name/title
+        description: Application description
+        version: Application version
+    """
+    global _app_metadata
+    _app_metadata = {
+        "name": name,
+        "description": description,
+        "version": version,
+    }
+    get_global_logger().debug(
+        f"App metadata set: {name} v{version} - {description[:50]}..."
+    )
+
+
+def get_app_metadata() -> Dict[str, str]:
+    """
+    Get stored application metadata.
+
+    Returns:
+        Dictionary with app metadata (name, description, version)
+    """
+    return _app_metadata.copy()
+
 
 class HelpResult(CommandResult):
     """
@@ -141,12 +178,15 @@ class HelpCommand(Command):
                 f"Получены метаданные для {len(all_commands_info.get('commands', {}))} команд"
             )
 
+            # Get app metadata (set during app creation)
+            app_metadata = get_app_metadata()
+
             # Prepare response format with tool metadata
             result = {
                 "tool_info": {
-                    "name": "MCP-Proxy API Service",
-                    "description": "JSON-RPC API for microservice command execution",
-                    "version": "1.0.0",
+                    "name": app_metadata["name"],
+                    "description": app_metadata["description"],
+                    "version": app_metadata["version"],
                 },
                 "help_usage": {
                     "description": "Get information about commands",
