@@ -28,6 +28,19 @@ class ProxyRegistrationCommandResult(SuccessResult):
     message: str = ""
     details: Optional[Dict[str, Any]] = None
 
+    def __post_init__(self):
+        """Initialize data attribute for SuccessResult compatibility."""
+        # Initialize data attribute if not already set
+        if not hasattr(self, 'data') or self.data is None:
+            self.data = {
+                "operation": self.operation,
+                "server_key": self.server_key,
+                "details": self.details,
+            }
+        # Ensure message is set
+        if not hasattr(self, 'message') or not self.message:
+            self.message = self.message if hasattr(self, 'message') else ""
+
 
 class ProxyRegistrationCommand(Command):
     """Proxy registration command with security framework integration."""
@@ -82,6 +95,14 @@ class ProxyRegistrationCommand(Command):
 
         required_permissions = operation_permissions.get(operation, ["read"])
 
+        # Get config - initialize if not present
+        if not hasattr(self, 'config') or self.config is None:
+            from mcp_proxy_adapter.config import get_config
+            try:
+                self.config = get_config().config_data
+            except Exception:
+                self.config = {}
+        
         # Check if security is enabled before checking permissions
         security_enabled = self.config.get("security", {}).get("enabled", False)
         
