@@ -10,6 +10,7 @@ from .start_job_command import QueueStartJobCommand
 from .stop_job_command import QueueStopJobCommand
 from .delete_job_command import QueueDeleteJobCommand
 from .get_status_command import QueueGetJobStatusCommand
+from .get_logs_command import QueueGetJobLogsCommand
 from .list_jobs_command import QueueListJobsCommand
 from .health_command import QueueHealthCommand
 from .jobs import (
@@ -21,14 +22,37 @@ from .jobs import (
     BatchProcessingJob,
     FileDownloadJob,
     CommandExecutionJob,
+    PeriodicLoggingJob,
 )
 
+# Auto-register all queue commands
+from mcp_proxy_adapter.commands.command_registry import registry
+
+_queue_commands = [
+    QueueAddJobCommand,
+    QueueStartJobCommand,
+    QueueStopJobCommand,
+    QueueDeleteJobCommand,
+    QueueGetJobStatusCommand,
+    QueueGetJobLogsCommand,
+    QueueListJobsCommand,
+    QueueHealthCommand,
+]
+
+for cmd_class in _queue_commands:
+    try:
+        registry.register(cmd_class, "builtin")
+    except Exception:
+        # Command may already be registered, ignore
+        pass
+
 __all__ = [
     "QueueAddJobCommand",
     "QueueStartJobCommand",
     "QueueStopJobCommand",
     "QueueDeleteJobCommand",
     "QueueGetJobStatusCommand",
+    "QueueGetJobLogsCommand",
     "QueueListJobsCommand",
     "QueueHealthCommand",
     "DataProcessingJob",
@@ -39,5 +63,6 @@ __all__ = [
     "BatchProcessingJob",
     "FileDownloadJob",
     "CommandExecutionJob",
+    "PeriodicLoggingJob",
 ]
 
