@@ -4,7 +4,7 @@ Module with base classes for command results.
 
 import json
 from abc import ABC, abstractmethod
-from typing import Any, Dict, List, Optional, Type, TypeVar, Union
+from typing import TypeVar, Dict, Any, Optional
 
 T = TypeVar("T", bound="CommandResult")
 
@@ -27,39 +27,13 @@ class CommandResult(ABC):
     @classmethod
     @abstractmethod
     def get_schema(cls) -> Dict[str, Any]:
-        """
-        Returns JSON schema for result validation.
-
-        Returns:
-            Dictionary with JSON schema.
-        """
+        """Get JSON schema for the result."""
         pass
 
-    def to_json(self, indent: Optional[int] = None) -> str:
-        """
-        Converts result to JSON string.
-
-        Args:
-            indent: Indentation for JSON formatting.
-
-        Returns:
-            JSON string with result.
-        """
-        return json.dumps(self.to_dict(), ensure_ascii=False, indent=indent)
-
     @classmethod
-    def from_dict(cls: Type[T], data: Dict[str, Any]) -> T:
-        """
-        Creates result instance from dictionary.
-        This method must be overridden in subclasses.
-
-        Args:
-            data: Dictionary with result data.
-
-        Returns:
-            Result instance.
-        """
-        raise NotImplementedError("Method from_dict must be implemented in subclasses")
+    def from_dict(cls, data: Dict[str, Any]) -> "CommandResult":
+        """Create result from dictionary."""
+        pass
 
 
 class SuccessResult(CommandResult):
@@ -96,34 +70,23 @@ class SuccessResult(CommandResult):
 
     @classmethod
     def get_schema(cls) -> Dict[str, Any]:
-        """
-        Returns JSON schema for result validation.
-
-        Returns:
-            Dictionary with JSON schema.
-        """
+        """Get JSON schema for success result."""
         return {
             "type": "object",
             "properties": {
-                "success": {"type": "boolean"},
+                "success": {"type": "boolean", "const": True},
                 "data": {"type": "object"},
-                "message": {"type": "string"},
-            },
-            "required": ["success"],
+                "message": {"type": "string"}
+            }
         }
 
     @classmethod
     def from_dict(cls, data: Dict[str, Any]) -> "SuccessResult":
-        """
-        Creates successful result instance from dictionary.
-
-        Args:
-            data: Dictionary with result data.
-
-        Returns:
-            Successful result instance.
-        """
-        return cls(data=data.get("data"), message=data.get("message"))
+        """Create success result from dictionary."""
+        return cls(
+            data=data.get("data"),
+            message=data.get("message")
+        )
 
 
 class ErrorResult(CommandResult):
@@ -167,43 +130,28 @@ class ErrorResult(CommandResult):
 
     @classmethod
     def get_schema(cls) -> Dict[str, Any]:
-        """
-        Returns JSON schema for result validation.
-
-        Returns:
-            Dictionary with JSON schema.
-        """
+        """Get JSON schema for error result."""
         return {
             "type": "object",
             "properties": {
-                "success": {"type": "boolean"},
+                "success": {"type": "boolean", "const": False},
                 "error": {
                     "type": "object",
                     "properties": {
                         "code": {"type": "integer"},
                         "message": {"type": "string"},
-                        "data": {"type": "object"},
-                    },
-                    "required": ["code", "message"],
-                },
-            },
-            "required": ["success", "error"],
+                        "data": {"type": "object"}
+                    }
+                }
+            }
         }
 
     @classmethod
     def from_dict(cls, data: Dict[str, Any]) -> "ErrorResult":
-        """
-        Creates error result instance from dictionary.
-
-        Args:
-            data: Dictionary with result data.
-
-        Returns:
-            Error result instance.
-        """
-        error = data.get("error", {})
+        """Create error result from dictionary."""
+        error_data = data.get("error", {})
         return cls(
-            message=error.get("message", "Unknown error"),
-            code=error.get("code", -32000),
-            details=error.get("data"),
+            code=error_data.get("code", -32603),
+            message=error_data.get("message", "Internal error"),
+            details=error_data.get("data")
         )
