@@ -42,6 +42,27 @@ class SettingsResult:
         self.all_settings = all_settings
         self.error_message = error_message
 
+    def to_dict(self) -> Dict[str, Any]:
+        """
+        Convert result to dictionary for JSON serialization.
+
+        Returns:
+            Dictionary with result data
+        """
+        result = {
+            "success": self.success,
+            "operation": self.operation,
+        }
+        if self.key:
+            result["key"] = self.key
+        if self.value is not None:
+            result["value"] = self.value
+        if self.all_settings:
+            result["all_settings"] = self.all_settings
+        if self.error_message:
+            result["error_message"] = self.error_message
+        return result
+
 
 class SettingsCommand(Command):
     """Command for managing framework settings."""
