@@ -8,10 +8,10 @@ Command for SSL/TLS configuration and certificate management.
 """
 
 import logging
-import ssl
 from typing import Dict, Any, Optional
 
 from mcp_proxy_adapter.core.logging import get_global_logger
+from mcp_proxy_adapter.core.ssl_utils import SSLUtils
 # Import mcp_security_framework
 try:
     from mcp_security_framework.core.ssl_manager import SSLManager
@@ -266,17 +266,17 @@ class SSLSetupCommand(Command):
         """Test SSL configuration using fallback method."""
         try:
             # Create SSL context
-            context = ssl.create_default_context(ssl.Purpose.CLIENT_AUTH)
-            context.check_hostname = False
-            context.verify_mode = ssl.CERT_NONE
-
-            # Load certificate and key
-            context.load_cert_chain(cert_file, key_file)
+            context = SSLUtils.create_ssl_context(
+                cert_file=cert_file,
+                key_file=key_file,
+                verify_client=False,
+                check_hostname=False,
+            )
 
             # Test basic SSL functionality
             details = {
                 "framework": "fallback (ssl module)",
-                "ssl_version": ssl.OPENSSL_VERSION,
+                "ssl_version": getattr(context, "version", lambda: "unknown")(),
                 "certificate_loaded": True,
                 "private_key_loaded": True,
                 "context_created": True,
@@ -294,7 +294,7 @@ class SSLSetupCommand(Command):
                     "error": str(e),
                     "details": {
                         "framework": "fallback (ssl module)",
-                        "ssl_version": ssl.OPENSSL_VERSION,
+                        "ssl_version": "unknown",
                         "certificate_loaded": False,
                         "private_key_loaded": False,
                         "context_created": False,
