@@ -16,7 +16,6 @@ import json
 import logging
 import time
 import uuid
-from datetime import datetime, timedelta
 from pathlib import Path
 from typing import Dict, List, Any, Optional, Union
 
@@ -25,6 +24,7 @@ from .result import SuccessResult, ErrorResult, CommandResult
 from ..core.auth_validator import AuthValidator
 
 
+from mcp_proxy_adapter.core.logging import get_global_logger
 class TokenManagementCommand(Command):
     """
     Token management commands.
@@ -87,7 +87,7 @@ class TokenManagementCommand(Command):
                 return ErrorResult(message=f"Unknown method: {method}", code=-32601)
 
         except Exception as e:
-            self.logger.error(f"Token management command execution error: {e}")
+            self.get_global_logger().error(f"Token management command execution error: {e}")
             return ErrorResult(
                 message=f"Token management command failed: {str(e)}", code=-32603
             )
@@ -121,7 +121,7 @@ class TokenManagementCommand(Command):
                 return await self._create_api_token(token_data)
 
         except Exception as e:
-            self.logger.error(f"Token creation error: {e}")
+            self.get_global_logger().error(f"Token creation error: {e}")
             return ErrorResult(message=f"Token creation failed: {str(e)}", code=-32603)
 
     async def token_validate(
@@ -164,7 +164,7 @@ class TokenManagementCommand(Command):
                 )
 
         except Exception as e:
-            self.logger.error(f"Token validation error: {e}")
+            self.get_global_logger().error(f"Token validation error: {e}")
             return ErrorResult(
                 message=f"Token validation failed: {str(e)}", code=-32603
             )
@@ -207,7 +207,7 @@ class TokenManagementCommand(Command):
             )
 
         except Exception as e:
-            self.logger.error(f"Token revocation error: {e}")
+            self.get_global_logger().error(f"Token revocation error: {e}")
             return ErrorResult(
                 message=f"Token revocation failed: {str(e)}", code=-32603
             )
@@ -260,7 +260,7 @@ class TokenManagementCommand(Command):
             )
 
         except Exception as e:
-            self.logger.error(f"Token listing error: {e}")
+            self.get_global_logger().error(f"Token listing error: {e}")
             return ErrorResult(message=f"Token listing failed: {str(e)}", code=-32603)
 
     async def token_refresh(self, token: str) -> Union[SuccessResult, ErrorResult]:
@@ -326,7 +326,7 @@ class TokenManagementCommand(Command):
             )
 
         except Exception as e:
-            self.logger.error(f"Token refresh error: {e}")
+            self.get_global_logger().error(f"Token refresh error: {e}")
             return ErrorResult(message=f"Token refresh failed: {str(e)}", code=-32603)
 
     async def _create_jwt_token(
@@ -371,7 +371,7 @@ class TokenManagementCommand(Command):
             )
 
         except Exception as e:
-            self.logger.error(f"JWT token creation error: {e}")
+            self.get_global_logger().error(f"JWT token creation error: {e}")
             return ErrorResult(
                 message=f"JWT token creation failed: {str(e)}", code=-32603
             )
@@ -420,7 +420,7 @@ class TokenManagementCommand(Command):
             )
 
         except Exception as e:
-            self.logger.error(f"API token creation error: {e}")
+            self.get_global_logger().error(f"API token creation error: {e}")
             return ErrorResult(
                 message=f"API token creation failed: {str(e)}", code=-32603
             )
@@ -460,7 +460,7 @@ class TokenManagementCommand(Command):
             return None
 
         except Exception as e:
-            self.logger.error(f"Failed to get token expiry: {e}")
+            self.get_global_logger().error(f"Failed to get token expiry: {e}")
             return None
 
     def _load_tokens(self) -> Dict[str, Any]:
@@ -478,7 +478,7 @@ class TokenManagementCommand(Command):
                 return json.load(f)
 
         except Exception as e:
-            self.logger.error(f"Failed to load tokens: {e}")
+            self.get_global_logger().error(f"Failed to load tokens: {e}")
             return {}
 
     def _save_tokens(self, tokens: Dict[str, Any]) -> None:
@@ -496,5 +496,5 @@ class TokenManagementCommand(Command):
                 json.dump(tokens, f, indent=2, ensure_ascii=False)
 
         except Exception as e:
-            self.logger.error(f"Failed to save tokens: {e}")
+            self.get_global_logger().error(f"Failed to save tokens: {e}")
             raise
