@@ -215,77 +215,14 @@ class CertificateValidator:
         Returns:
             True if certificate is valid according to system CA store, False otherwise
         """
+        from mcp_proxy_adapter.core.ssl_utils import SSLUtils
+
         try:
-            import ssl
-            import socket
-            from cryptography import x509
-
-            # Load certificate
-            with open(cert_path, "rb") as f:
-                cert_data = f.read()
-                cert = x509.load_pem_x509_certificate(cert_data)
-
-            # Get certificate subject common name or SAN
-            try:
-                # Try to get CN from subject
-                cn = cert.subject.get_attributes_for_oid(x509.NameOID.COMMON_NAME)[
-                    0
-                ].value
-                hostname = cn
-            except (IndexError, AttributeError):
-                # Try to get from SAN
-                try:
-                    san = cert.extensions.get_extension_for_oid(
-                        x509.ExtensionOID.SUBJECT_ALTERNATIVE_NAME
-                    )
-                    if san.value:
-                        hostname = san.value.get_values_for_type(x509.DNSName)[0]
-                    else:
-                        hostname = "localhost"
-                except (x509.ExtensionNotFound, IndexError):
-                    hostname = "localhost"
-
-            # Create SSL context with system CA store
-            context = ssl.create_default_context()
-            context.check_hostname = False  # We're only checking certificate validity
-
-            # Create a temporary socket to validate the certificate
-            # We'll use a dummy connection approach
-            try:
-                # Try to validate certificate by creating a certificate object
-                # and checking it against the system store
-                # This is a simplified check - in production, you might want
-                # to use OpenSSL or certifi for more robust validation
-                from cryptography.hazmat.primitives import serialization
-
-                cert_bytes = cert.public_bytes(serialization.Encoding.PEM)
-
-                # Use certifi if available for system CA bundle
-                try:
-                    import certifi
-
-                    ca_bundle = certifi.where()
-                    context.load_verify_locations(ca_bundle)
-                except ImportError:
-                    # Use system default
-                    pass
-
-                # For validation, we check if certificate is not expired
-                # and has valid structure
-                if not CertificateValidator.validate_certificate_not_expired(cert_path):
-                    return False
-
-                # Additional check: verify certificate structure
-                # This is a basic check - full chain validation would require
-                # connecting to the server or having the full chain
-                return True
-
-            except Exception as e:
-                logger.error(f"Failed to validate certificate with system store: {e}")
+            if not CertificateValidator.validate_certificate_not_expired(cert_path):
                 return False
-
-        except Exception as e:
-            logger.error(f"Failed to validate certificate with system store: {e}")
+            return SSLUtils.validate_certificate(cert_path)
+        except Exception as exc:  # noqa: BLE001
+            logger.error(f"Failed to validate certificate with system store: {exc}")
             return False
 
     @staticmethod
