@@ -8,8 +8,7 @@ Author: Vasiliy Zdanovskiy
 email: vasilyvz@gmail.com
 """
 
-import ssl
-from typing import Dict, Any, Optional, List, Tuple
+from typing import Dict, Any, Optional, List, Tuple, TYPE_CHECKING
 from pathlib import Path
 
 # Import framework utilities
@@ -39,6 +38,10 @@ except ImportError as e:
     ValidationResult = None
 
 from mcp_proxy_adapter.core.logging import get_global_logger
+from mcp_proxy_adapter.core.ssl_utils import SSLUtils
+
+if TYPE_CHECKING:
+    from ssl import SSLContext
 
 
 class ClientSecurityManager:
@@ -96,7 +99,7 @@ class ClientSecurityManager:
 
     def create_client_ssl_context(
         self, server_hostname: Optional[str] = None
-    ) -> Optional[ssl.SSLContext]:
+    ) -> Optional["SSLContext"]:
         """
         Create SSL context for client connections.
 
@@ -126,7 +129,7 @@ class ClientSecurityManager:
         self,
         cert_config: Optional[Dict[str, Any]] = None,
         ssl_config: Optional[Dict[str, Any]] = None,
-    ) -> Optional[ssl.SSLContext]:
+    ) -> Optional["SSLContext"]:
         """
         Create SSL context from certificate and SSL configuration dictionaries.
         
@@ -163,23 +166,14 @@ class ClientSecurityManager:
                 )
                 return None
 
-            # Create SSL context
-            context = ssl.create_default_context(ssl.Purpose.SERVER_AUTH)
-            
-            # Load CA certificate if provided
-            if ca_cert_file:
-                context.load_verify_locations(ca_cert_file)
-                context.verify_mode = ssl.CERT_REQUIRED
-            else:
-                # If no CA provided, disable verification (for testing)
-                context.check_hostname = False
-                context.verify_mode = ssl.CERT_NONE
-
-            # Load client certificate and key
-            context.load_cert_chain(cert_file, key_file)
-            
-            # Set hostname checking
-            context.check_hostname = check_hostname
+            verify = bool(ca_cert_file)
+            context = SSLUtils.create_client_ssl_context(
+                ca_cert=ca_cert_file,
+                client_cert=cert_file,
+                client_key=key_file,
+                verify=verify,
+                check_hostname=check_hostname,
+            )
 
             get_global_logger().info(
                 f"SSL context created with cert: {cert_file}, key: {key_file}, "
@@ -350,7 +344,7 @@ class ClientSecurityManager:
 
     def prepare_client_connection(
         self, server_config: Dict[str, Any]
-    ) -> Tuple[Optional[ssl.SSLContext], Dict[str, str]]:
+    ) -> Tuple[Optional["SSLContext"], Dict[str, str]]:
         """
         Prepare secure client connection to server.
 
