@@ -40,13 +40,6 @@ class SimpleConfigGenerator:
         server_debug: Optional[bool] = None,
         server_log_level: Optional[str] = None,
         server_log_dir: Optional[str] = None,
-        # Client parameters
-        client_enabled: bool = False,
-        client_protocol: Optional[str] = None,
-        client_cert_file: Optional[str] = None,
-        client_key_file: Optional[str] = None,
-        client_ca_cert_file: Optional[str] = None,
-        client_crl_file: Optional[str] = None,
         # Registration parameters
         registration_host: Optional[str] = None,
         registration_port: Optional[int] = None,
@@ -63,7 +56,7 @@ class SimpleConfigGenerator:
         
         Args:
             protocol: Server protocol (http, https, mtls)
-            with_proxy: Enable proxy registration (deprecated, use registration parameters)
+            with_proxy: Enable proxy registration (always True when generating config)
             out_path: Output file path
             # Server parameters
             server_host: Server host (default: 0.0.0.0)
@@ -75,13 +68,6 @@ class SimpleConfigGenerator:
             server_debug: Enable debug mode (default: False)
             server_log_level: Log level: DEBUG, INFO, WARNING, ERROR, CRITICAL (default: INFO)
             server_log_dir: Log directory path (default: ./logs)
-            # Client parameters
-            client_enabled: Enable client configuration
-            client_protocol: Client protocol (http, https, mtls)
-            client_cert_file: Client certificate file path
-            client_key_file: Client key file path
-            client_ca_cert_file: Client CA certificate file path
-            client_crl_file: Client CRL file path
             # Registration parameters
             registration_host: Registration proxy host (default: localhost)
             registration_port: Registration proxy port (default: 3005)
@@ -128,19 +114,8 @@ class SimpleConfigGenerator:
             log_dir=server_log_dir or "./logs",  # Default: ./logs
         )
 
-        # Client configuration
-        client = ClientConfig(enabled=client_enabled)
-        if client_enabled:
-            client.protocol = client_protocol or protocol
-            if client.protocol in ("https", "mtls"):
-                client_ssl = SSLConfig(
-                    cert=client_cert_file or "./certs/client.crt",
-                    key=client_key_file or "./certs/client.key",
-                    ca=client_ca_cert_file or ("./certs/ca.crt" if client.protocol == "mtls" else None),
-                    crl=client_crl_file,
-                    dnscheck=False,
-                )
-                client.ssl = client_ssl
+        # Client configuration (always disabled - not used)
+        client = ClientConfig(enabled=False)
 
         # Registration configuration
         if with_proxy:
@@ -168,7 +143,7 @@ class SimpleConfigGenerator:
                     key=registration_key_file or "./certs/registration.key",
                     ca=registration_ca_cert_file or ("./certs/ca.crt" if reg_protocol == "mtls" else None),
                     crl=registration_crl_file,
-                    dnscheck=True,  # Default true for registration
+                    dnscheck=False if reg_protocol == "mtls" else True,  # Disable DNS check for mTLS by default
                 )
             
             # Create registration config with new format
@@ -190,6 +165,7 @@ class SimpleConfigGenerator:
                 enabled=False,
                 protocol="http",
                 register_url="http://localhost:3005/register",  # Default value, not used when disabled
+                unregister_url="http://localhost:3005/unregister",  # Default value, not used when disabled
                 heartbeat_interval=30,  # Required field even when disabled
                 heartbeat=HeartbeatConfig(url="http://localhost:3005/proxy/heartbeat", interval=30),
             )
