@@ -5,11 +5,14 @@ email: vasilyvz@gmail.com
 SSL management for proxy registration.
 """
 
-import ssl
-from typing import Dict, Any, Optional
+from typing import Dict, Any, Optional, TYPE_CHECKING
 from urllib.parse import urlparse
 
 from mcp_proxy_adapter.core.logging import get_global_logger
+from mcp_proxy_adapter.core.ssl_utils import SSLUtils
+
+if TYPE_CHECKING:
+    from ssl import SSLContext
 
 
 class SSLManager:
@@ -31,7 +34,7 @@ class SSLManager:
         self.proxy_url = proxy_url
         self.logger = get_global_logger()
 
-    def get_ssl_context(self) -> Optional[ssl.SSLContext]:
+    def get_ssl_context(self) -> Optional["SSLContext"]:
         """
         Get SSL context for secure connections (alias for create_ssl_context).
         
@@ -40,7 +43,7 @@ class SSLManager:
         """
         return self.create_ssl_context()
 
-    def create_ssl_context(self) -> Optional[ssl.SSLContext]:
+    def create_ssl_context(self) -> Optional["SSLContext"]:
         """
         Create SSL context for secure connections using registration SSL configuration.
 
@@ -136,11 +139,10 @@ class SSLManager:
                     return None
             else:
                 self.logger.info("🔍 [SSL] No SSL configuration found for registration, creating default context (verify disabled)")
-                # Create a default SSL context that doesn't verify certificates (for testing)
-                context = ssl.create_default_context()
-                context.check_hostname = False
-                context.verify_mode = ssl.CERT_NONE
-                return context
+                return SSLUtils.create_client_ssl_context(
+                    verify=False,
+                    check_hostname=False,
+                )
 
         except Exception as e:
             self.logger.error(f"🔍 [SSL] Error creating SSL context for registration: {e}", exc_info=True)
