@@ -14,13 +14,16 @@ accepts explicit parameters for clarity and portability.
 """
 
 import json
-import ssl
 from dataclasses import dataclass
-from typing import Any, Dict, Optional, Tuple
+from typing import Any, Dict, Optional, Tuple, TYPE_CHECKING
 from urllib.parse import urljoin
 
 import aiohttp  # type: ignore[import]
 
+from mcp_proxy_adapter.core.ssl_utils import SSLUtils
+
+if TYPE_CHECKING:
+    from ssl import SSLContext
 
 @dataclass(frozen=True)
 class RegistrationRequest:
@@ -74,8 +77,8 @@ class ProxyClient:
         client_cert_path: str,
         client_key_path: str,
         request_timeout_s: float = 5.0,
-        min_tls_version: ssl.TLSVersion = ssl.TLSVersion.TLSv1_2,
-        verify_mode: ssl.VerifyMode = ssl.CERT_REQUIRED,
+        min_tls_version: str = "TLSv1.2",
+        verify_mode: str = "CERT_REQUIRED",
     ) -> None:
         """
         Initialize proxy client.
@@ -96,10 +99,14 @@ class ProxyClient:
         self._client_cert_path: str = client_cert_path
         self._client_key_path: str = client_key_path
         self._request_timeout_s: float = request_timeout_s
-        self._min_tls_version: ssl.TLSVersion = min_tls_version
-        self._verify_mode: ssl.VerifyMode = verify_mode
+        self._min_tls_version: str = (
+            getattr(min_tls_version, "value", min_tls_version)  # Handle ssl.TLSVersion
+        )
+        self._verify_mode: str = (
+            verify_mode.name if hasattr(verify_mode, "name") else str(verify_mode)
+        )
 
-        self._ssl_context: Optional[ssl.SSLContext] = None
+        self._ssl_context: Optional["SSLContext"] = None
         self._session: Optional[aiohttp.ClientSession] = None
 
     async def __aenter__(self) -> "ProxyClient":
@@ -151,19 +158,21 @@ class ProxyClient:
         self._session = None
         self._ssl_context = None
 
-    def _build_ssl_context(self) -> ssl.SSLContext:
+    def _build_ssl_context(self) -> "SSLContext":
         """
         Build SSL context for mTLS connections.
         
         Returns:
             Configured SSL context
         """
-        ctx = ssl.create_default_context(ssl.Purpose.SERVER_AUTH)
-        ctx.minimum_version = self._min_tls_version
-        ctx.verify_mode = self._verify_mode
-        ctx.load_verify_locations(self._ca_cert_path)
-        ctx.load_cert_chain(self._client_cert_path, self._client_key_path)
-        return ctx
+        return SSLUtils.create_client_ssl_context(
+            ca_cert=self._ca_cert_path,
+            client_cert=self._client_cert_path,
+            client_key=self._client_key_path,
+            verify=self._verify_mode != "CERT_NONE",
+            min_tls_version=self._min_tls_version,
+            check_hostname=True,
+        )
 
     async def _get_json(self, path: str) -> Tuple[int, Dict[str, Any]]:
         """
