@@ -9,7 +9,6 @@ email: vasilyvz@gmail.com
 """
 
 import logging
-import ssl
 from typing import Dict, Any, Optional
 
 from .server_engine import ServerEngineFactory, ServerEngine
@@ -69,9 +68,6 @@ class ServerConfigAdapter:
             hypercorn_ssl["ca_certs"] = ca_cert
 
         # Map verification mode
-        if ssl_config.get("verify_client", False):
-            hypercorn_ssl["verify_mode"] = ssl.CERT_REQUIRED
-
         # Map hostname checking - support both new (dnscheck) and old (chk_hostname) formats
         dnscheck = ssl_config.get("dnscheck")
         if dnscheck is not None:
