@@ -70,10 +70,39 @@ class Settings:
         cls._custom_settings.clear()
 
     @staticmethod
+    def get_all_settings() -> Dict[str, Any]:
+        """
+        Get all settings from configuration and custom settings.
 
-    @staticmethod
-
-    @staticmethod
+        Returns:
+            Dictionary with all settings (custom + config)
+        """
+        all_settings = {}
+        
+        # Get custom settings
+        all_settings.update(Settings.get_custom_settings())
+        
+        # Get config settings (if config is available)
+        try:
+            # Try to get main config sections
+            if hasattr(config, 'config_data') and config.config_data:
+                all_settings.update(config.config_data)
+            elif hasattr(config, 'get'):
+                # Get common settings from config
+                common_keys = [
+                    "server.host", "server.port", "server.debug",
+                    "logging.level", "logging.log_dir",
+                    "commands.auto_discovery", "commands.discovery_path",
+                ]
+                for key in common_keys:
+                    value = config.get(key)
+                    if value is not None:
+                        all_settings[key] = value
+        except Exception:
+            # If config access fails, just return custom settings
+            pass
+        
+        return all_settings
 
     @staticmethod
     def get_custom_setting(key: str, default: Any = None) -> Any:
