@@ -10,9 +10,9 @@ to SecurityConfig format used by mcp_security_framework.
 
 import json
 import logging
-from typing import Dict, Any, Optional, List, Union
 from pathlib import Path
 from dataclasses import dataclass
+from typing import List, Dict, Any
 
 # Import mcp_security_framework components
 try:
@@ -25,15 +25,14 @@ try:
     )
 
     SECURITY_FRAMEWORK_AVAILABLE = True
-except ImportError:
-    SECURITY_FRAMEWORK_AVAILABLE = False
-    SecurityConfig = None
-    AuthConfig = None
-    SSLConfig = None
-    PermissionConfig = None
-    RateLimitConfig = None
+except ImportError as e:
+    # NO FALLBACK! mcp_security_framework is REQUIRED
+    raise RuntimeError(
+        f"CRITICAL: mcp_security_framework is required but not available: {e}. "
+        "Install it with: pip install mcp_security_framework>=1.2.8"
+    ) from e
 
-from mcp_proxy_adapter.core.logging import logger
+from mcp_proxy_adapter.core.logging import get_global_logger
 
 
 @dataclass
@@ -71,53 +70,6 @@ class UnifiedConfigAdapter:
         self.validation_errors = []
         self.validation_warnings = []
 
-    def convert_to_security_config(
-        self, config: Dict[str, Any]
-    ) -> Optional[SecurityConfig]:
-        """
-        Convert mcp_proxy_adapter configuration to SecurityConfig.
-
-        Args:
-            config: mcp_proxy_adapter configuration dictionary
-
-        Returns:
-            SecurityConfig instance or None if conversion failed
-        """
-        if not SECURITY_FRAMEWORK_AVAILABLE:
-            logger.error(
-                "mcp_security_framework not available, cannot convert configuration"
-            )
-            return None
-
-        try:
-            # Validate configuration first
-            validation_result = self.validate_configuration(config)
-            if not validation_result.is_valid:
-                logger.error(
-                    f"Configuration validation failed: {validation_result.errors}"
-                )
-                return None
-
-            # Convert configuration sections
-            auth_config = self._convert_auth_config(config)
-            ssl_config = self._convert_ssl_config(config)
-            permission_config = self._convert_permission_config(config)
-            rate_limit_config = self._convert_rate_limit_config(config)
-
-            # Create SecurityConfig
-            security_config = SecurityConfig(
-                auth=auth_config,
-                ssl=ssl_config,
-                permissions=permission_config,
-                rate_limit=rate_limit_config,
-            )
-
-            logger.info("Configuration successfully converted to SecurityConfig")
-            return security_config
-
-        except Exception as e:
-            logger.error(f"Failed to convert configuration: {e}")
-            return None
 
     def validate_configuration(self, config: Dict[str, Any]) -> ValidationResult:
         """
@@ -457,10 +409,44 @@ class UnifiedConfigAdapter:
 
         permissions_config = security_config.get("permissions", {})
 
-        # Merge with legacy roles config
+        # Handle security.roles - convert to role_mappings format
+        security_roles = security_config.get("roles", {})
+        if security_roles:
+            # Convert roles format to role_mappings
+            # If roles is a dict where values are lists (token -> roles mapping)
+            # or dict where values are objects with permissions field
+            role_mappings = {}
+            for role_name, role_value in security_roles.items():
+                if isinstance(role_value, list):
+                    # Format: "role_name": ["permission1", "permission2"]
+                    role_mappings[role_name] = role_value
+                elif isinstance(role_value, dict):
+                    # Format: "role_name": {"permissions": [...], "description": "..."}
+                    # Extract permissions field
+                    if "permissions" in role_value:
+                        role_mappings[role_name] = role_value["permissions"]
+                    else:
+                        # If no permissions field, use empty list
+                        role_mappings[role_name] = []
+                else:
+                    # Single string permission
+                    role_mappings[role_name] = [role_value] if isinstance(role_value, str) else []
+            
+            # Set role_mappings in permissions_config
+            if role_mappings:
+                permissions_config["role_mappings"] = role_mappings
+
+        # Merge with legacy roles config (from root level)
         legacy_roles = config.get("roles", {})
-        if legacy_roles:
-            permissions_config.update(legacy_roles)
+        if legacy_roles and isinstance(legacy_roles, dict):
+            # Convert legacy roles format if needed
+            if "role_mappings" not in permissions_config:
+                permissions_config["role_mappings"] = {}
+            for role_name, role_value in legacy_roles.items():
+                if isinstance(role_value, list):
+                    permissions_config["role_mappings"][role_name] = role_value
+                elif isinstance(role_value, dict) and "permissions" in role_value:
+                    permissions_config["role_mappings"][role_name] = role_value["permissions"]
 
         return permissions_config
 
@@ -480,151 +466,6 @@ class UnifiedConfigAdapter:
 
         return rate_limit_config
 
-    def get_public_paths(self, config: Dict[str, Any]) -> List[str]:
-        """
-        Get public paths from configuration.
 
-        Args:
-            config: Configuration dictionary
 
-        Returns:
-            List of public paths
-        """
-        security_config = config.get("security", {})
 
-        # Ensure security_config is a dictionary
-        if not isinstance(security_config, dict):
-            return ["/health", "/docs", "/redoc", "/openapi.json", "/favicon.ico"]
-
-        public_paths = security_config.get("public_paths", [])
-
-        # Add default public paths if none specified
-        if not public_paths:
-            public_paths = [
-                "/health",
-                "/docs",
-                "/redoc",
-                "/openapi.json",
-                "/favicon.ico",
-            ]
-
-        return public_paths
-
-    def get_security_enabled(self, config: Dict[str, Any]) -> bool:
-        """
-        Check if security is enabled in configuration.
-
-        Args:
-            config: Configuration dictionary
-
-        Returns:
-            True if security is enabled
-        """
-        security_config = config.get("security", {})
-
-        # Ensure security_config is a dictionary
-        if not isinstance(security_config, dict):
-            return True  # Default to enabled for safety
-
-        return security_config.get("enabled", True)
-
-    def migrate_legacy_config(self, config: Dict[str, Any]) -> Dict[str, Any]:
-        """
-        Migrate legacy configuration to new format.
-
-        Args:
-            config: Legacy configuration dictionary
-
-        Returns:
-            Migrated configuration dictionary
-        """
-        migrated_config = config.copy()
-
-        # Create security section if it doesn't exist
-        if "security" not in migrated_config:
-            migrated_config["security"] = {}
-
-        security_config = migrated_config["security"]
-
-        # Migrate SSL configuration
-        if "ssl" in migrated_config and "ssl" not in security_config:
-            security_config["ssl"] = migrated_config["ssl"]
-            # Don't remove legacy SSL yet for backward compatibility
-
-        # Migrate roles configuration
-        if "roles" in migrated_config and "permissions" not in security_config:
-            security_config["permissions"] = migrated_config["roles"]
-            # Don't remove legacy roles yet for backward compatibility
-
-        # Migrate auth_enabled flag
-        if "auth_enabled" in migrated_config and "auth" not in security_config:
-            security_config["auth"] = {"enabled": migrated_config["auth_enabled"]}
-
-        # Migrate rate_limit_enabled flag
-        if (
-            "rate_limit_enabled" in migrated_config
-            and "rate_limit" not in security_config
-        ):
-            security_config["rate_limit"] = {
-                "enabled": migrated_config["rate_limit_enabled"]
-            }
-
-        logger.info("Legacy configuration migrated to new format")
-        return migrated_config
-
-    def get_default_config(self) -> Dict[str, Any]:
-        """
-        Get default configuration.
-
-        Returns:
-            Default configuration dictionary
-        """
-        return {
-            "security": {
-                "enabled": True,
-                "auth": {
-                    "enabled": True,
-                    "methods": ["api_key"],
-                    "api_keys": {},
-                    "jwt_secret": "",
-                    "jwt_algorithm": "HS256",
-                    "jwt_expiration": 3600,
-                },
-                "ssl": {
-                    "enabled": False,
-                    "cert_file": None,
-                    "key_file": None,
-                    "ca_cert": None,
-                    "min_tls_version": "TLSv1.2",
-                    "verify_client": False,
-                    "client_cert_required": False,
-                    "cipher_suites": [],
-                },
-                "permissions": {
-                    "enabled": True,
-                    "roles_file": "roles.json",
-                    "default_role": "user",
-                    "deny_by_default": True,
-                    "role_mappings": {},
-                },
-                "rate_limit": {
-                    "enabled": True,
-                    "requests_per_minute": 60,
-                    "requests_per_hour": 1000,
-                    "requests_per_day": 10000,
-                    "burst_limit": 10,
-                    "by_ip": True,
-                    "by_user": True,
-                    "by_endpoint": False,
-                    "exempt_roles": [],
-                    "exempt_endpoints": [],
-                },
-                "public_paths": [
-                    "/health",
-                    "/docs",
-                    "/redoc",
-                    "/openapi.json",
-                    "/favicon.ico",
-                ],
-            }
-        }
