@@ -126,8 +126,8 @@ class ConfigValidator:
         """Validate for unknown configuration fields."""
         known_sections = {
             "server", "protocols", "security", "ssl", "auth", "roles", 
-            "logging", "commands", "proxy_registration", "transport",
-            "client", "registration", "server_validation"  # SimpleConfig format sections
+            "logging", "commands", "transport",
+            "client", "registration", "server_validation", "queue_manager"  # SimpleConfig format sections
         }
         
         for section in self.config_data.keys():
@@ -141,7 +141,7 @@ class ConfigValidator:
 
     def _validate_uuid_format(self) -> None:
         """Validate UUID format in configuration."""
-        uuid_fields = ["server.server_id", "proxy_registration.server_id"]
+        uuid_fields = ["server.server_id", "registration.server_id"]
         
         for field in uuid_fields:
             value = self._get_nested_value_safe(field)
