@@ -7,7 +7,6 @@ This example demonstrates advanced usage of MCP Proxy Adapter including:
 - Role-based access control
 """
 
-from .main import get_app
-
-app = get_app()
+# Note: main.py doesn't export get_app, it's a standalone script
+# Import proxy router for use in other modules if needed
 from .proxy_endpoints import router as proxy_router
