@@ -16,13 +16,13 @@ from pathlib import Path
 
 from mcp_proxy_adapter.api.app import create_app
 from mcp_proxy_adapter.core.server_engine import ServerEngineFactory
-from mcp_proxy_adapter.core.server_adapter import ServerConfigAdapter
 from mcp_proxy_adapter.commands.command_registry import registry
 from mcp_proxy_adapter.core.config.simple_config import SimpleConfig
 from mcp_proxy_adapter.config import get_config
+from mcp_proxy_adapter.core.app_factory.ssl_config import build_server_ssl_config
 
 
-def register_all_commands():
+def register_all_commands() -> None:
     """Register all available commands (built-in, load, queue, custom, dynamic)."""
     from mcp_proxy_adapter.commands.load_command import LoadCommand
     from mcp_proxy_adapter.commands.help_command import HelpCommand
@@ -40,6 +40,7 @@ def register_all_commands():
         from mcp_proxy_adapter.examples.full_application.commands.custom_echo_command import (
             CustomEchoCommand,
         )
+
         registry.register(CustomEchoCommand, "custom")
         print("✅ Custom echo command registered")
     except Exception as e:
@@ -50,36 +51,28 @@ def register_all_commands():
         from mcp_proxy_adapter.examples.full_application.commands.dynamic_calculator_command import (
             DynamicCalculatorCommand,
         )
+
         registry.register(DynamicCalculatorCommand, "custom")
         print("✅ Dynamic calculator command registered")
     except Exception as e:
         print(f"⚠️  Dynamic calculator command not available: {e}")
 
-    # Register queue commands (will fail gracefully if queuemgr not available)
+    # Register long-running command with queue
     try:
-        from mcp_proxy_adapter.commands.queue_commands import (
-            QueueAddJobCommand,
-            QueueStartJobCommand,
-            QueueStopJobCommand,
-            QueueDeleteJobCommand,
-            QueueGetJobStatusCommand,
-            QueueListJobsCommand,
-            QueueHealthCommand,
+        from mcp_proxy_adapter.examples.full_application.commands.long_running_command import (
+            LongRunningCommand,
         )
 
-        registry.register(QueueAddJobCommand, "builtin")
-        registry.register(QueueStartJobCommand, "builtin")
-        registry.register(QueueStopJobCommand, "builtin")
-        registry.register(QueueDeleteJobCommand, "builtin")
-        registry.register(QueueGetJobStatusCommand, "builtin")
-        registry.register(QueueListJobsCommand, "builtin")
-        registry.register(QueueHealthCommand, "builtin")
-        print("✅ Queue commands registered")
+        registry.register(LongRunningCommand, "custom")
+        print("✅ Long-running command registered")
     except Exception as e:
-        print(f"⚠️  Queue commands not available: {e}")
+        print(f"⚠️  Long-running command not available: {e}")
+
+    # Note: Queue commands are automatically registered by register_builtin_commands()
+    # if queue_manager is enabled in configuration. No manual registration needed.
 
 
-def main():
+def main() -> None:
     """Minimal runnable entrypoint for full application example."""
     parser = argparse.ArgumentParser(description="MCP Proxy Adapter Full Application")
     parser.add_argument("--config", required=True, help="Path to configuration file")
@@ -127,7 +120,7 @@ def main():
     # Update global configuration instance used by adapter internals
     cfg = get_config()
     cfg.config_path = str(cfg_path)
-    cfg.model = model
+    setattr(cfg, "model", model)
     cfg.config_data = app_config
     if hasattr(cfg, "feature_manager"):
         cfg.feature_manager.config_data = cfg.config_data
@@ -164,9 +157,7 @@ def main():
                 "Set transport.verify_client=true."
             )
         if not ca_cert_file:
-            raise SystemExit(
-                "CRITICAL CONFIG ERROR: 'mtls' requires server.ssl.ca."
-            )
+            raise SystemExit("CRITICAL CONFIG ERROR: 'mtls' requires server.ssl.ca.")
 
     app = create_app(
         title="Full Application Example",
@@ -197,24 +188,13 @@ def main():
         "reload": False,
     }
 
-    # Add SSL configuration from server section (new ssl structure)
-    ssl_config = server_cfg.get("ssl", {})
-    if ssl_config:
-        # Use ServerConfigAdapter to convert SSL config
-        # Prepare SSL config dict (new format: cert, key, ca)
-        ssl_config_dict = {
-            "cert": ssl_config.get("cert"),
-            "key": ssl_config.get("key"),
-            "ca": ssl_config.get("ca"),
-            "dnscheck": ssl_config.get("dnscheck", False),
-            "verify_client": (server_cfg.get("protocol") == "mtls") or transport.get("verify_client", False),
-        }
-        
-        # Convert to engine format
-        hypercorn_ssl = ServerConfigAdapter.convert_ssl_config_for_engine(
-            ssl_config_dict, "hypercorn"
-        )
-        server_config.update(hypercorn_ssl)
+    try:
+        ssl_engine_config = build_server_ssl_config(app_config)
+        if ssl_engine_config:
+            server_config.update(ssl_engine_config)
+    except ValueError as exc:
+        print(f"❌ SSL configuration invalid: {exc}")
+        raise SystemExit(1)
 
     # Optional proxy registration - support both old (proxy_registration) and new (registration) formats
     pr = {}
@@ -291,7 +271,7 @@ def main():
     engine = ServerEngineFactory.get_engine("hypercorn")
     if not engine:
         raise RuntimeError("Hypercorn engine not available")
-    
+
     engine.run_server(app, server_config)
 
 
