@@ -190,7 +190,7 @@ class ProxyListResult(SuccessResult):
 
 class ProxyRegisterCommand(Command):
     """Register a server with the proxy."""
-    
+
     name = "proxy_register"
     descr = "Register a server with the proxy"
 
@@ -232,8 +232,14 @@ class ProxyRegisterCommand(Command):
         }
 
     async def execute(
-        self, server_id: str = None, name: str = None, server_url: str = None, url: str = None,
-        capabilities: List[str] = None, metadata: Dict[str, Any] = None, **kwargs
+        self,
+        server_id: str = None,
+        name: str = None,
+        server_url: str = None,
+        url: str = None,
+        capabilities: List[str] = None,
+        metadata: Dict[str, Any] = None,
+        **kwargs,
     ) -> ProxyRegisterResult:
         """Execute proxy register command.
 
@@ -441,7 +447,7 @@ class ProxyRegisterCommand(Command):
 
 class ProxyUnregisterCommand(Command):
     """Unregister a server from the proxy."""
-    
+
     name = "proxy_unregister"
     descr = "Unregister a server from the proxy"
 
@@ -491,7 +497,7 @@ class ProxyUnregisterCommand(Command):
 
 class ProxyHeartbeatCommand(Command):
     """Update server heartbeat."""
-    
+
     name = "proxy_heartbeat"
     descr = "Update server heartbeat"
 
@@ -509,12 +515,38 @@ class ProxyHeartbeatCommand(Command):
                     "type": "string",
                     "description": "Server name (alternative to server_id)",
                 },
+                "server_url": {
+                    "type": "string",
+                    "description": "Server URL (required if server is not registered yet)",
+                },
+                "url": {
+                    "type": "string",
+                    "description": "Server URL (alternative to server_url)",
+                },
+                "capabilities": {
+                    "type": "array",
+                    "items": {"type": "string"},
+                    "description": "Server capabilities",
+                    "default": [],
+                },
+                "metadata": {
+                    "type": "object",
+                    "description": "Additional server metadata",
+                    "default": {},
+                },
             },
             "required": [],
         }
 
     async def execute(
-        self, server_id: str = None, name: str = None, **kwargs
+        self,
+        server_id: str = None,
+        name: str = None,
+        server_url: str = None,
+        url: str = None,
+        capabilities: List[str] = None,
+        metadata: Dict[str, Any] = None,
+        **kwargs,
     ) -> ProxyHeartbeatResult:
         """Execute proxy heartbeat command."""
         if server_id is None:
@@ -522,6 +554,15 @@ class ProxyHeartbeatCommand(Command):
         if name and not server_id:
             server_id = name
 
+        if server_url is None:
+            server_url = kwargs.get("server_url") or kwargs.get("url", "")
+        if url and not server_url:
+            server_url = url
+        if capabilities is None:
+            capabilities = kwargs.get("capabilities", [])
+        if metadata is None:
+            metadata = kwargs.get("metadata", {})
+
         if not server_id:
             return ErrorResult(
                 message="server_id (or name) is required",
@@ -529,8 +570,31 @@ class ProxyHeartbeatCommand(Command):
             )
 
         heartbeat_received = False
-        if server_id in _registry and "default" in _registry[server_id]:
-            _registry[server_id]["default"]["last_heartbeat"] = time.time()
+        entry = _registry.setdefault(server_id, {}).get("default")
+        if entry is None:
+            if not server_url:
+                return ErrorResult(
+                    message="server_url (or url) is required for first heartbeat from server",
+                    code=-32602,
+                )
+            entry = {
+                "server_id": server_id,
+                "server_url": server_url,
+                "capabilities": capabilities or [],
+                "metadata": metadata or {},
+                "registered_at": time.time(),
+                "last_heartbeat": time.time(),
+            }
+            _registry[server_id]["default"] = entry
+            heartbeat_received = True
+        else:
+            if server_url:
+                entry["server_url"] = server_url
+            if capabilities is not None:
+                entry["capabilities"] = capabilities
+            if metadata is not None:
+                entry["metadata"] = metadata
+            entry["last_heartbeat"] = time.time()
             heartbeat_received = True
 
         return ProxyHeartbeatResult(
@@ -541,7 +605,7 @@ class ProxyHeartbeatCommand(Command):
 
 class ProxyListCommand(Command):
     """List all registered servers."""
-    
+
     name = "proxy_list"
     descr = "List all registered servers"
 
