@@ -15,6 +15,7 @@ import time
 from typing import Dict, Any, List
 
 from mcp_proxy_adapter.commands.command_registry import registry
+from mcp_proxy_adapter.commands.queue_commands import (
     QueueAddJobCommand,
     QueueStartJobCommand,
     QueueStopJobCommand,
@@ -34,6 +35,7 @@ class MockQueueManager:
     """Mock queue manager for demonstration purposes."""
     
     def __init__(self):
+        """Initialize mock queue storage."""
         self.jobs: Dict[str, Dict[str, Any]] = {}
         self.running = True
     
