@@ -20,10 +20,11 @@ except Exception as e:
 
 # List all registered commands
 print("\nRegistered commands:")
-for name, command in registry._builtin_commands.items():
-    print(f"  - {name}: {command.__class__.__name__}")
+all_commands = registry.get_all_commands() if hasattr(registry, 'get_all_commands') else registry._commands
+for name, command in all_commands.items():
+    print(f"  - {name}: {command.__name__ if hasattr(command, '__name__') else command.__class__.__name__}")
 
-print(f"\nTotal commands: {len(registry._builtin_commands)}")
+print(f"\nTotal commands: {len(all_commands)}")
 
 # Test echo command
 try:
