@@ -7,6 +7,10 @@ import os
 import asyncio
 sys.path.insert(0, os.path.join(os.path.dirname(__file__), 'mcp_proxy_adapter'))
 
+# Skip this file in pytest runs - it's a standalone script
+import pytest
+pytest.skip("Standalone scenario", allow_module_level=True)
+
 from mcp_proxy_adapter.api.handlers import execute_command
 from mcp_proxy_adapter.commands.command_registry import registry
 from mcp_proxy_adapter.commands.builtin_commands import register_builtin_commands
